/*
 * Jednoduche kresleni v C#.
 * 
 * Jiri Skala, unor 2008
 * 
 */
using System;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;

namespace SimpleDrawing
{
	/// <summary>
	/// Jednoduche kresleni.
	/// </summary>
	public partial class SimpleDrawing : Form
	{
		/// <summary>
		/// Uhel otoceni kulicky podel kruznice.
		/// </summary>
		private float angle = 0;

		/// <summary>
		/// Pero pro kresleni car.
		/// </summary>
		private Pen penLine;





		/// <summary>
		/// Uhlovy krok otaceni kulicky podel kruznice.
		/// </summary>
		private const float angleIncrement = 0.1f;

		/// <summary>
		/// Polomer kruznice, po ktere bude behat kulicka.
		/// </summary>
		private const float circleRadius = 200;

		/// <summary>
		/// Polomer kulicky, ktera bude behat po kruznici.
		/// </summary>
		private const float marbleRadius = 10;

		/// <summary>
		/// Popisky tlacitka.
		/// </summary>
		private const string textRunAnim = "Spust animaci";
		private const string textStopAnim = "Zastav animaci";





		/// <summary>
		/// Konstruktor.
		/// </summary>
		public SimpleDrawing()
		{
			// pripravime GUI
			InitializeComponent();

			// ujistime se, ze bude na tlacitku spravny popisek
			buttonAnimate.Text = textRunAnim;

			// pripravime pero pro kresleni car (cerne, 3 pixely tluste)
			penLine = new Pen(Color.Black, 3);
			// nastavime prerusovanou caru (10 bodu cara, 4 mezera, 2 cara, 4 mezera a pak znovu dokola)
			penLine.DashPattern = new float[] { 10, 4, 2, 4 };
		}

		/// <summary>
		/// Vytazeno ze SimpleDrawing.Designer.cs.
		/// 
		/// Uvolnime zdroje, ktere jsme alokovali pro nase kresleni.
		/// 
		/// Clean up any resources being used.
		/// </summary>
		/// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				// zrusime komponenty okna
				if (components != null)
					components.Dispose();

				// zrusime nase pero
				if (penLine != null)
					penLine.Dispose();
			}

			base.Dispose(disposing);
		}

		/// <summary>
		/// Metoda ktera se vyvola pri kresleni panelu.
		/// Nevolat primo (vlastne ani nema smysl), pouzivat panelCanvas.Invalidate().
		/// </summary>
		private void panelCanvas_Paint(object sender, PaintEventArgs e)
		{
			// ziskame Graphics objekt pro kresleni
			Graphics gr = e.Graphics;

			// zjistime velikost panelu
			float w = panelCanvas.Width;
			float h = panelCanvas.Height;

			// smazeme obsah panelu
			gr.Clear(Color.White);

			// spocitame souradnice stredu kruznice
			float cx = w / 2f;
			float cy = h / 2f;

			// nakreslime kruznici
			gr.DrawEllipse(penLine, cx-circleRadius, cy-circleRadius, 2*circleRadius, 2*circleRadius);

			// spocitame souradnice stredu kulicky
			float mx = cx + circleRadius * (float)Math.Sin(angle);
			float my = cy - circleRadius * (float)Math.Cos(angle);

			// nakreslime kulicku
			gr.FillEllipse(Brushes.Blue, mx-marbleRadius, my-marbleRadius, 2*marbleRadius, 2*marbleRadius);
		}

		/// <summary>
		/// Reakce na stisknuti tlacitka.
		/// </summary>
		private void buttonDraw_Click(object sender, EventArgs e)
		{
			// spustime/zastavime animaci
			timer.Enabled = ! timer.Enabled;

			// nastavime popisek tlacitka
			if (timer.Enabled)
				buttonAnimate.Text = textStopAnim;
			else
				buttonAnimate.Text = textRunAnim;
		}

		/// <summary>
		/// Reakce na tiknuti casovace.
		/// </summary>
		private void timer_Tick(object sender, EventArgs e)
		{
			// pootocime kulicku podel kruznice
			angle += angleIncrement;

			// pohlidame uhel v intervalu <0, 2pi)
			if (angle >= 2*Math.PI)
				angle -= (float)(2*Math.PI);

			// prekreslime obrazek
			panelCanvas.Invalidate();
		}
	}
}
